!=================================================================
!
! NAME: 
!
!    ErrorHandler
!
! FUNCTION:
!
!    Handles errors ina systematic way
!
! TYPE/LANGUAGE: 
!
!    F90 module
!
! DESCRIPTION:  
!
!    Outputs an error message and stops program in a systematic way
!
! ROUTINES TO BE USED EXTERNALLY:
!
! ROUTINES USED INTERNALLY:
!
! HISTORY:
! 
!   Original version by Jonathan P.D. Mittaz on 9/18/2013
!
!=================================================================
MODULE ErrorHandler

  IMPLICIT NONE

CONTAINS

  !=================================================================
  !
  ! NAME:
  !
  !      out_ERROR
  !
  ! FUNCTION:
  !
  !      Outputs error description to user and stops program
  !
  ! TYPE/LANGUAGE:
  !
  !      Fortran 90
  !
  ! DESCRIPTION:
  !
  !      Outputs error description to user and stops program
  !
  ! SUBROUTINE/FUNCTION CALLS:
  !
  ! CALLING SEQUENCE:
  !
  ! INPUTS:
  ! 
  !      string     - Error string
  !      routine    - Routine calling the subroutine
  !      filename   - File containing the module calling the subroutine
  !
  ! RETURNS:
  !
  ! HISTORY
  !
  !      Original F90 version by Jonathan P.D. Mittaz 8/14/2013
  !
  SUBROUTINE out_ERROR( string, routine, filename )

    CHARACTER(LEN=*), INTENT(IN) :: string
    CHARACTER(LEN=*), INTENT(IN) :: routine
    CHARACTER(LEN=*), INTENT(IN) :: filename

    !
    ! Output error message
    !
    WRITE(*,'(''ERROR:   '',a)')TRIM(string)
    WRITE(*,'(''ROUTINE: '',a)')TRIM(routine)
    WRITE(*,'(''FILE:    '',a)')TRIM(filename)
    STOP 1

  END SUBROUTINE out_ERROR

END MODULE ErrorHandler
