!=================================================================
!
! NAME: 
!
!    Kinds
!
! FUNCTION:
!
!    Kinds used by the code
!
! TYPE/LANGUAGE: 
!
!    F90 module
!
! DESCRIPTION:  
!
!    Defines the INTEGER/REAL Types used by the code
!
!    Note, default for RealType is REAL*8 (double precision).  To change to 
!    REAL*4 (single precision) replace the line
!
!    INTEGER, PARAMETER :: RealType = SELECTED_REAL_KIND( P =  13 , R =  300 )
!
!    with
!
!    INTEGER, PARAMETER :: RealType = SELECTED_REAL_KIND( P =  6 , R =  37 )
!
! ROUTINES TO BE USED EXTERNALLY:
!
! ROUTINES USED INTERNALLY:
!
! HISTORY:
! 
!   Original version by Jonathan P.D. Mittaz on 7/16/2013
!
!=================================================================
MODULE Kinds

  IMPLICIT NONE

!-----------------------------------------------------------------------------
!
! Type Kinds for Fortran 90 code to recalibrate the AVHRR
!
! Defines the following types
!
!     INTEGER(Int1)    :   1 byte integer
!     INTEGER(Int2)    :   1 byte integer
!     INTEGER(Int3)    :   1 byte integer
!     INTEGER(Int4)    :   1 byte integer
!     REAL(RealType    :   4 byte real
!     REAL(Dble)       :   8 byte real
!
! Writted By Jonathan Mittaz, UMD/CICS 
!
! HISTORY
!
! Original Version: 7/16/2013
!
  INTEGER, PARAMETER :: Int1 = SELECTED_INT_KIND( 2 )                  ! 1 byte integer
  INTEGER, PARAMETER :: Int2 = SELECTED_INT_KIND( 4 )                  ! 2 byte integer
  INTEGER, PARAMETER :: Int4 = SELECTED_INT_KIND( 9 )                  ! 4 byte integer
  INTEGER, PARAMETER :: Int8 = SELECTED_INT_KIND( 18 )                 ! 8 byte integer

  INTEGER, PARAMETER :: RealType = SELECTED_REAL_KIND( P =  13 , R =  300 ) ! 8 byte double precision

  INTEGER, PARAMETER :: Dble = SELECTED_REAL_KIND( P = 13 , R = 300 )  ! 8 byte real
END MODULE Kinds
